@@ -46,5 +46,10 @@ def from_load(load):
 	trans_data['origin_location_name'] = load.origin_location_name
 	trans_data['destination_location_id'] = load.destination_location_id
 	trans_data['destination_location_name'] = load.destination_location_name
+	trans_data['delivery_open_time'] = load.delivery_open_time
+	trans_data['delivery_close_time'] = load.delivery_close_time
+	trans_data['pickup_open_time'] = load.pickup_open_time
+	trans_data['pickup_close_time'] = load.pickup_close_time
+
 	transaction = Transaction(**trans_data)
 	return transaction
