@@ -99,3 +99,7 @@ class Transaction:
     origin_location_name: str = field(default=None)
     destination_location_id: str = field(default=None)
     destination_location_name: str = field(default=None)
+    delivery_open_time: datetime.time = field(default=None)
+    delivery_close_time: datetime.time = field(default=None)
+    pickup_open_time: datetime.time = field(default=None)
+    pickup_close_time: datetime.time = field(default=None)
