@@ -95,6 +95,10 @@ class TransactionSchema(CamelCaseSchema):
 	origin_location_name = fields.String(allow_none=None)
 	destination_location_id = fields.String(allow_none=None)
 	destination_location_name = fields.String(allow_none=None)
+	delivery_open_time = fields.Time(allow_none=True)
+	delivery_close_time = fields.Time(allow_none=True)
+	pickup_open_time = fields.Time(allow_none=True)
+	pickup_close_time = fields.Time(allow_none=True)
 
 	@post_load
 	def classify(self, data, **kwargs):
